==> kubernetes-model-1.0.60-sources.jar: annotations/io/fabric8/openshift/api/model/TagImportPolicyBuilder.java <==
package io.fabric8.openshift.api.model;

import javax.validation.Validation;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.util.Set;
import javax.annotation.Generated;
import javax.validation.ValidationException;
import javax.validation.ValidatorFactory;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import javax.validation.ConstraintViolation;
import javax.validation.ConstraintViolationException;
import java.lang.Object;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import java.lang.Boolean;
import lombok.ToString;
import io.sundr.builder.annotations.Buildable;
import javax.validation.Validator;

public class TagImportPolicyBuilder extends TagImportPolicyFluentImpl<TagImportPolicyBuilder> implements VisitableBuilder<TagImportPolicy,TagImportPolicyBuilder>{

    TagImportPolicyFluent<?> fluent;
    Boolean validationEnabled;

    public TagImportPolicyBuilder(){
            this(true);
    }
    public TagImportPolicyBuilder(Boolean validationEnabled){
            this(new TagImportPolicy(), validationEnabled);
    }
    public TagImportPolicyBuilder(TagImportPolicyFluent<?> fluent){
            this(fluent, true);
    }
    public TagImportPolicyBuilder(TagImportPolicyFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new TagImportPolicy(), validationEnabled);
    }
    public TagImportPolicyBuilder(TagImportPolicyFluent<?> fluent,TagImportPolicy instance){
            this(fluent, instance, true);
    }
    public TagImportPolicyBuilder(TagImportPolicyFluent<?> fluent,TagImportPolicy instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withInsecure(instance.getInsecure()); 
            fluent.withScheduled(instance.getScheduled()); 
            this.validationEnabled = validationEnabled; 
    }
    public TagImportPolicyBuilder(TagImportPolicy instance){
            this(instance,true);
    }
    public TagImportPolicyBuilder(TagImportPolicy instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withInsecure(instance.getInsecure()); 
            this.withScheduled(instance.getScheduled()); 
            this.validationEnabled = validationEnabled; 
    }

    public TagImportPolicy build(){
            TagImportPolicy buildable = new TagImportPolicy(fluent.isInsecure(),fluent.isScheduled());
            validate(buildable);
            return buildable;
    }

    private <T>void validate(T item){
            if (!validationEnabled) { return; }
            Validator validator = null;
            try {
                ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
                validator = factory.getValidator();
            } catch(ValidationException e) {return;}
            Set<ConstraintViolation<T>> violations = validator.validate(item);
            if (!violations.isEmpty()) {
            throw new ConstraintViolationException(violations);
             }
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            TagImportPolicyBuilder that = (TagImportPolicyBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}

==> kubernetes-model-2.0.10-sources.jar: annotations/io/fabric8/openshift/api/model/TagImportPolicyBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class TagImportPolicyBuilder extends TagImportPolicyFluentImpl<TagImportPolicyBuilder> implements VisitableBuilder<TagImportPolicy,TagImportPolicyBuilder>{

    TagImportPolicyFluent<?> fluent;
    Boolean validationEnabled;

    public TagImportPolicyBuilder(){
            this(true);
    }
    public TagImportPolicyBuilder(Boolean validationEnabled){
            this(new TagImportPolicy(), validationEnabled);
    }
    public TagImportPolicyBuilder(TagImportPolicyFluent<?> fluent){
            this(fluent, true);
    }
    public TagImportPolicyBuilder(TagImportPolicyFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new TagImportPolicy(), validationEnabled);
    }
    public TagImportPolicyBuilder(TagImportPolicyFluent<?> fluent,TagImportPolicy instance){
            this(fluent, instance, true);
    }
    public TagImportPolicyBuilder(TagImportPolicyFluent<?> fluent,TagImportPolicy instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withInsecure(instance.getInsecure()); 
            fluent.withScheduled(instance.getScheduled()); 
            this.validationEnabled = validationEnabled; 
    }
    public TagImportPolicyBuilder(TagImportPolicy instance){
            this(instance,true);
    }
    public TagImportPolicyBuilder(TagImportPolicy instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withInsecure(instance.getInsecure()); 
            this.withScheduled(instance.getScheduled()); 
            this.validationEnabled = validationEnabled; 
    }

    public TagImportPolicy build(){
            TagImportPolicy buildable = new TagImportPolicy(fluent.isInsecure(),fluent.isScheduled());
            io.fabric8.kubernetes.api.builder.ValidationUtils.validate(buildable);
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            TagImportPolicyBuilder that = (TagImportPolicyBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}
